<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="36"/>
        <source>Click to change color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="65"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="197"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Configuración del comando personalizado</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="211"/>
        <source>Use icon from theme or browse file</source>
        <translation>Use el icono del tema o busque el archivo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Ejecutar con «bash -c»</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="42"/>
        <source>Select Font</source>
        <translation>Elegir la tipografía</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="72"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Font</source>
        <translation>Tipografía</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="268"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="238"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="241"/>
        <source>Use %1 to display command output</source>
        <translation>Usar %1 para mostrar la salida del comando</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="201"/>
        <source>Icon</source>
        <translation>Icono</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="218"/>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Autorotar cuando el panel esté en vertical</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="94"/>
        <source>echo Configure...</source>
        <translation>echo Configurar...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="97"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="308"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="325"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="342"/>
        <source>Command to run</source>
        <translation>Comando a ejecutar</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="258"/>
        <source>Max Width</source>
        <translation>Ancho máximo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="156"/>
        <source>Repeat command after:</source>
        <translation>Repetir el comando tras:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="52"/>
        <source>Text Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="62"/>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="172"/>
        <source> second(s)</source>
        <translation> segundo(s)</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="194"/>
        <source>Command outputs an image</source>
        <translation>El comando genera una imagen</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="248"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Mouse Commands</source>
        <translation>Comandos del ratón</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="298"/>
        <source>Click</source>
        <translation>Clic</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="315"/>
        <source>Wheel Up</source>
        <translation>Rueda hacia arriba</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="332"/>
        <source>Wheel Down</source>
        <translation>Rueda hacia abajo</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Select Icon File</source>
        <translation>Seleccionar el archivo del icono</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="166"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Imágenes (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
